import VODUpload from './../../util/aliyun-upload-sdk-1.0.0.min.js'

Page({
    //页面的初始数据
    data: {
        options: {},
        files: [],
        images: [],
        count: 9, // 最多可以选择的图片张数
        videos: [],
        videosCount: 9 // 最多可以选择的视频数
    },
    onLoad: function (option) {
        this.setData({
            options: option
        });
    },
    onReady: function () {
        var that = this;

        var uploader = new VODUpload({
            timeout: that.data.options.timeout || 60000,
            region: that.data.options.region || "cn-shanghai",
            // 添加文件成功
            addFileSuccess: function (uploadInfo) {
                console.log("addFileSuccess" + JSON.stringify(uploadInfo))
            },
            // 开始上传
            onUploadstarted: function (uploadInfo) {
                console.log('文件开始上传...');
                console.log("onUploadStarted:" + JSON.stringify(uploadInfo))
                wx.request({
                    url: "https://alivc-demo.aliyuncs.com/demo/getSts",
                    // data: data,
                    // header: header,
                    // method: method,
                    success: (res => {
                        if (res.statusCode === 200) {
                            var akInfo = res.data.data;
                            uploader.setSTSToken(uploadInfo, akInfo.accessKeyId, akInfo.accessKeySecret, akInfo.securityToken);
                        } else {
                            console.log(res)
                        }
                    }),
                    fail: (res => {
                        onError(res);
                    })
                });

            },
            // 文件上传成功
            onUploadSucceed: function (uploadInfo) {
                console.log("onUploadSucceed: " + uploadInfo.file.name + ", endpoint:" + uploadInfo.endpoint + ", bucket:" + uploadInfo.bucket + ", object:" + uploadInfo.object)
                console.log('文件上传成功!')
            },
            // 文件上传失败
            onUploadFailed: function (uploadInfo, code, message) {
                console.log("onUploadFailed: file:" + uploadInfo.file.name + ",code:" + code + ", message:" + message)
                console.log('文件上传失败!')
            },
            // 取消文件上传
            onUploadCanceled: function (uploadInfo, code, message) {
                console.log("Canceled file: " + uploadInfo.file.name + ", code: " + code + ", message:" + message)
                console.log('文件已暂停上传!')

            },
            // 文件上传进度，单位：字节, 可以在这个函数中拿到上传进度并显示在页面上
            onUploadProgress: function (uploadInfo, totalSize, progress) {

                var files;
                if (uploadInfo.isImage) {
                    files = that.data.images;
                } else {
                    files = that.data.videos;
                }

                files.forEach((file, idx) => {
                    if (file.url === uploadInfo.url) {
                        file.progress = progress;
                        if (uploadInfo.isImage) {
                            that.setData({
                                images: files
                            })
                        } else {
                            that.setData({
                                videos: files
                            })
                        }
                    }
                })

                // console.log("onUploadProgress:file:" + uploadInfo.file.name + ", fileSize:" + totalSize + ", percent:" + Math.ceil(progress * 100) + "%")
                // var progressPercent = Math.ceil(progress * 100)
                // console.log('文件上传中...' + progressPercent);
                // $('#sts-progress').text(progressPercent)
                // $('#status').text('文件上传中...')

            },
            // 上传凭证超时
            onUploadTokenExpired: function (uploadInfo) {
                // // 如果是上传方式二即根据 STSToken 实现时，从新获取STS临时账号用于恢复上传
                // // 上传文件过大时可能在上传过程中 sts token 就会失效, 所以需要在 token 过期的回调中调用 resumeUploadWithSTSToken 方法
                // // 这里是测试接口, 所以我直接获取了 STSToken
                // $('#status').text('文件上传超时!')
                //
                // var stsUrl = 'http://demo-vod.cn-shanghai.aliyuncs.com/voddemo/CreateSecurityToken?BusinessType=vodai&TerminalType=pc&DeviceModel=iPhone9,2&UUID=67999yyuuuy&AppVersion=1.0.0'
                // $.get(stsUrl, function (data) {
                //     var info = data.SecurityTokenInfo
                //     var accessKeyId = info.AccessKeyId
                //     var accessKeySecret = info.AccessKeySecret
                //     var secretToken = info.SecurityToken
                //     var expiration = info.Expiration
                //     uploader.resumeUploadWithSTSToken(accessKeyId, accessKeySecret, secretToken, expiration)
                // }, 'json')
            },
            // 全部文件上传结束
            onUploadEnd: function (uploadInfo) {
                wx.showToast({
                    title: '上传成功',
                    icon: 'success',
                    duration: 2000 // 提示的延迟时间
                })
                console.log("文件上传完毕 onUploadEnd: uploaded all the files")
            }
        });

        this.setData({
            uploader: uploader
        });


    },
    //选择图片
    chooseImage: function (e) {

        var that = this;
        var count = that.data.count; // 最多可以选择的图片张数
        wx.chooseImage({
            count: count, // 最多可以选择的图片张数
            sizeType: ['original', 'compressed'], // 可以指定是原图还是压缩图，默认二者都有
            sourceType: ['album', 'camera'], // 可以指定来源是相册还是相机，默认二者都有
            success: function (res) {

                var length = res.tempFilePaths.length; // 获取本次选择图片的数量
                count -= length;
                // 返回选定照片的本地文件路径列表，tempFilePath可以作为img标签的src属性显示图片

                res.tempFilePaths.forEach(item => {
                    that.data.images = that.data.images.concat({'url': item})
                });

                that.setData({
                    count: count,
                    images: that.data.images
                });

                that.data.images.forEach(item => {
                    var uploader = that.data.uploader;
                    var userData = '{"Vod":{}}';
                    uploader.addFile(item, null, null, null, userData)
                })
            }
        })
    },
    removeImage: function (event) {
        this.setData({
            count: ++this.data.count
        });
        var url = event.currentTarget.id;
        this.data.images.forEach((image, idx) => {
            if (image.url === url) {
                this.data.images.splice(idx, 1);
                this.data.uploader.deleteFile(idx);
                this.setData({
                    images: this.data.images
                });
            }
        })
    },
    // 选择视频
    chooseVideo: function (e) {
        var that = this;
        wx.chooseVideo({
            sourceType: ['album', 'camera'],
            maxDuration: 60,
            compressed: false,
            camera: 'back',
            success: function (res) {
                var file = {url: res.tempFilePath, coverUrl: res.thumbTempFilePath};
                var videosCount = --that.data.videosCount;
                that.setData({
                    videosCount: videosCount,
                    videos: that.data.videos.concat(file)
                });

                var uploader = that.data.uploader;
                var userData = '{"Vod":{}}'
                uploader.addFile(file, null, null, null, userData)

            }
        })
    },
    removeVideo: function (event) {
        this.setData({
            videosCount: ++this.data.videosCount
        });
        var url = event.currentTarget.id;
        this.data.videos.forEach((video, idx) => {
            if (video.url === url) {
                this.data.videos.splice(idx, 1);
                this.data.uploader.deleteFile(idx);
                this.setData({
                    videos: this.data.videos
                });
            }
        })

    },
    // 预览图片
    previewImage: function (e) {
        wx.previewImage({
            current: e.currentTarget.id, // 当前显示图片的http链接
            urls: [e.currentTarget.id] // 需要预览的图片http链接列表
        })
    },
    //点击上传
    uploadImg: function (e) {
        this.data.uploader.startUpload();
    },
    uploadVideo: function (e) {
        this.data.uploader.startUpload();
    },
    _getSuffix: function (filename) {
        var pos = filename.lastIndexOf('.')
        var suffix = ''
        if (pos != -1) {
            suffix = filename.substring(++pos)
        }
        return suffix;
    }
})